package fachada;

import java.sql.SQLException;
import java.util.Vector;

import execoes.CamposObrigatoriosException;
import execoes.DadoInexistenteException;

import negocios.NegocioCliente;
import negocios.NegocioDepartamento;
import negocios.NegocioFuncionario;
import negocios.NegocioModelo;
import negocios.NegocioServico;
import negocios.NegocioVeiculo;
import Iterators.IteratorCliente;
import Iterators.IteratorDepartamento;
import Iterators.IteratorFuncionario;
import Iterators.IteratorModelo;
import Iterators.IteratorServico;
import Iterators.IteratorVeiculo;
import basicas.Cliente;
import basicas.Departamento;
import basicas.Endereco;
import basicas.Funcionario;
import basicas.Modelo;
import basicas.Servico;
import basicas.Telefone;
import basicas.Veiculo;

public class Fachada {

	private static Fachada instancia;
	private NegocioCliente negocioCliente;
	private NegocioDepartamento negocioDepartamento;
	private NegocioFuncionario negocioFuncionario;
	private NegocioServico negocioServico;
	private NegocioVeiculo negocioVeiculo;
	private NegocioModelo negocioModelo;

	public Fachada() throws ClassNotFoundException, SQLException {
		negocioCliente = new NegocioCliente();
		negocioDepartamento = new NegocioDepartamento();
		negocioFuncionario = new NegocioFuncionario();
		negocioServico = new NegocioServico();
		negocioVeiculo = new NegocioVeiculo();
		negocioModelo = new NegocioModelo();
	}

	public static Fachada getInstace() throws ClassNotFoundException, SQLException {
		if (instancia == null) {
			instancia = new Fachada();
		}
		return instancia;
	}

	//Metodos Negocio Cliente
	public boolean cadastrarCliente(String nome, String email, String cpf,
			Endereco endereco, Vector<Telefone> telefones)
			throws CamposObrigatoriosException, SQLException {
		return negocioCliente.cadastrar(nome, email, cpf, endereco, telefones);
	}

	public boolean editarCliente(int numeroDeCadastro, String nome,
			String email, String cpf, Endereco endereco,
			Vector<Telefone> telefones) throws CamposObrigatoriosException, SQLException {
		return negocioCliente.editar(numeroDeCadastro, nome, email, cpf,
				endereco, telefones);
	}

	public boolean removerCliente(int numeroDeCadastro) throws SQLException {
		return negocioCliente.remover(numeroDeCadastro);
	}

	public Cliente buscarCliente(int numeroDeCadastro)
			throws DadoInexistenteException, SQLException {
		return negocioCliente.buscar(numeroDeCadastro);
	}

	public IteratorCliente buscarTodosClientes() throws DadoInexistenteException {
		return negocioCliente.buscarTodos();
	}

	public IteratorCliente buscarClientesComParametro(String campoEscolhido,
			String valor) throws DadoInexistenteException {
		return negocioCliente.buscaComParametros(campoEscolhido, valor);
	}

	// Fim Metodos Negocio Cliente

	//Metodos Negocio Departamento
	public boolean cadastrarDepartamento(String nome, String local,
			int numeroFuncionario) throws CamposObrigatoriosException {
		return negocioDepartamento.cadastrar(nome, local, numeroFuncionario);
	}

	public boolean editarDepartamento(int numeroDoDepartamento, String nome,
			String local, int numeroFuncionario)
			throws CamposObrigatoriosException {
		return negocioDepartamento.editar(numeroDoDepartamento, nome, local,
				numeroFuncionario);
	}

	public Departamento buscarDepartamento(int numeroDeCadastro)
			throws DadoInexistenteException {
		return negocioDepartamento.buscar(numeroDeCadastro);
	}

	public boolean removerDepartamento(int numeroDeCadastro) {
		return negocioDepartamento.remover(numeroDeCadastro);
	}

	public IteratorDepartamento buscarTodosDepartamentos()
			throws DadoInexistenteException {
		return negocioDepartamento.buscarTodos();
	}

	public IteratorDepartamento buscarDepartamentosComParametros(
			String campoEscolhido, String valor)
			throws DadoInexistenteException {
		return negocioDepartamento.buscaComParametros(campoEscolhido, valor);
	}

	//Fim Metodos Negocio Departamento

	//Metodos Negocio Funcionario
	public Funcionario buscarFuncionario(int numeroDeCadastro)
			throws DadoInexistenteException {
		return negocioFuncionario.buscar(numeroDeCadastro);
	}

	public boolean cadastrarFuncionario(String nome, String senha,
			String dataDeNascimento, String cpf, String rg, String cargo,
			double salario, int numeroDepartamento, Endereco endereco,
			Vector<Telefone> telefones) throws CamposObrigatoriosException,
			DadoInexistenteException {
		return negocioFuncionario.cadastrar(nome, senha, dataDeNascimento, cpf,
				rg, cargo, salario, numeroDepartamento, endereco, telefones);
	}

	public boolean editarFuncionario(int numeroDeCadastro, String nome,
			String senha, String dataDeNascimento, String cpf, String rg,
			String cargo, double salario, int numeroDepartamento,
			Endereco endereco, Vector<Telefone> telefones)
			throws CamposObrigatoriosException, DadoInexistenteException {
		return negocioFuncionario.editar(numeroDeCadastro, nome, senha,
				dataDeNascimento, cpf, rg, cargo, salario, numeroDepartamento,
				endereco, telefones);
	}

	public boolean removerFuncionario(int numeroDeCadastro) {
		return negocioFuncionario.remover(numeroDeCadastro);
	}

	public IteratorFuncionario buscarTodosFuncionarios()
			throws DadoInexistenteException {
		return negocioFuncionario.buscarTodos();
	}

	public IteratorFuncionario buscarFuncionariosComParametro(String campoEscolhido,
			String valor) throws DadoInexistenteException {
		return negocioFuncionario.buscaComParametros(campoEscolhido, valor);
	}

	public boolean efetuarLogin(int cadastro, String senha)
			throws DadoInexistenteException {
		return negocioFuncionario.efetuarLogin(cadastro, senha);
	}

	//Fim Metodos Negocio Funcionario

	//Metodos Negocio Servico
	public Servico buscarServico(int numeroDeCadastro)
			throws DadoInexistenteException {
		return negocioServico.buscar(numeroDeCadastro);
	}

	public boolean cadastrarServico(String pagamento, double valor,
			String dataHora, double desconto, String descricao,
			int numeroDeCadastroVeiculo, int numeroDeCadastroCliente,
			Vector<Funcionario> funcionarios)
			throws CamposObrigatoriosException, DadoInexistenteException, SQLException {
		return negocioServico.cadastrar(pagamento, valor, dataHora, desconto,
				descricao, numeroDeCadastroVeiculo, numeroDeCadastroCliente,
				funcionarios);
	}

	public boolean editarServico(int numeroDeCadastroServico, String pagamento,
			double valor, String dataHora, double desconto, String descricao,
			int numeroDeCadastroVeiculo, int numeroDeCadastroCliente,
			Vector<Funcionario> funcionarios)
			throws CamposObrigatoriosException, DadoInexistenteException, SQLException {
		return negocioServico.editar(numeroDeCadastroServico, pagamento, valor,
				dataHora, desconto, descricao, numeroDeCadastroVeiculo,
				numeroDeCadastroCliente, funcionarios);
	}

	public boolean removerServico(int numeroDeCadastro) {
		return negocioServico.remover(numeroDeCadastro);
	}

	public IteratorServico buscarTodosServicos() throws DadoInexistenteException {
		return negocioServico.buscarTodos();
	}

	public IteratorServico buscarServicosComParametro(String campoEscolhido,
			String valor) throws DadoInexistenteException {
		return negocioServico.buscaComParametros(campoEscolhido, valor);
	}

	//Fim Metodos Negocio Servico

	//Metodo Negocio Veiculo
	public Veiculo buscarVeiculo(int numeroDeCadastro)
			throws DadoInexistenteException {
		return negocioVeiculo.buscar(numeroDeCadastro);
	}

	public boolean removerVeiculo(int numeroDeCadastro) {
		return negocioVeiculo.remover(numeroDeCadastro);
	}

	public boolean cadastrarVeiculo(String ano, String cor, String placa,
			String chassi, int numeroModelo) throws CamposObrigatoriosException {
		return negocioVeiculo.cadastrar(ano, cor, placa, chassi, numeroModelo);
	}

	public boolean editarVeiculo(int numeroCadastroVeiculo, String ano,
			String cor, String placa, String chassi, int numeroModelo)
			throws CamposObrigatoriosException {
		return negocioVeiculo.editar(numeroCadastroVeiculo, ano, cor, placa,
				chassi, numeroModelo);
	}

	public IteratorVeiculo buscarTodosVeiculos() throws DadoInexistenteException {
		return negocioVeiculo.buscarTodos();
	}

	public IteratorVeiculo buscarVeiculosComParametro(String campoEscolhido,
			String valor) throws DadoInexistenteException {
		return negocioVeiculo.buscaComParametros(campoEscolhido, valor);
	}

	//Fim Metodos Negocio Veiculo

	//Metodos Negocio Modelo
	public Modelo buscarModelo(int numeroDeCadastro)
			throws DadoInexistenteException {
		return negocioModelo.buscar(numeroDeCadastro);
	}

	public boolean cadastrarModelo(String marca, String modelo)
			throws CamposObrigatoriosException {
		return negocioModelo.cadastrar(marca, modelo);
	}

	public boolean editarModelo(int numeroDeCadastro, String marca,
			String modelo) throws CamposObrigatoriosException {
		return negocioModelo.editar(numeroDeCadastro, marca, modelo);
	}

	public boolean removerModelo(int numeroDeCadastro) {
		return negocioModelo.remover(numeroDeCadastro);
	}

	public IteratorModelo buscarTodosModelos() throws DadoInexistenteException {
		return negocioModelo.buscarTodos();
	}

	public IteratorModelo buscarModelosComParametro(String campoEscolhido,
			String valor) throws DadoInexistenteException {
		return negocioModelo.buscaComParametros(campoEscolhido, valor);
	}
	//Fim Metodos Negocio Modelo
}
