package negocios;

import execoes.CamposObrigatoriosException;
import execoes.DadoInexistenteException;
import repositorio.RepDepartamento;
import repositorio.RepFuncionario;
import Iterators.IteratorDepartamento;
import basicas.Departamento;
import basicas.Funcionario;
import interfaceNegocio.INegocioDepartamento;

public class NegocioDepartamento implements INegocioDepartamento {

	private RepDepartamento repositorio;
	private RepFuncionario repositorioFuncionario;
	
	public NegocioDepartamento(){
		repositorio = new RepDepartamento();
		repositorioFuncionario = new RepFuncionario();
	}
	

	public boolean cadastrar(String nome, String local, int numeroFuncionario) throws CamposObrigatoriosException{
		
		if(nome.trim().equals("") || local.trim().equals("") || numeroFuncionario == 0){
    		throw new CamposObrigatoriosException();
    	}
    	
		Funcionario funcionarioComNumero = new Funcionario();
		funcionarioComNumero.setNumeroDeCadastro(numeroFuncionario);
		
		Funcionario gerente = repositorioFuncionario.buscar(funcionarioComNumero);
		Departamento departamento = new Departamento(nome, local, gerente);
		
		if(gerente == null){
			return false;
		}else{
			return repositorio.cadastrar(departamento);
		}
	}

	public boolean editar(int numeroDoDepartamento, String nome, String local, int numeroFuncionario) throws CamposObrigatoriosException {
		
		if(nome.trim().equals("") || local.trim().equals("") || numeroFuncionario == 0){
    		throw new CamposObrigatoriosException();
    	}
    			
		Funcionario funcionarioComNumero = new Funcionario();
		funcionarioComNumero.setNumeroDeCadastro(numeroFuncionario);
		
		Funcionario funcionario = repositorioFuncionario.buscar(funcionarioComNumero);
		Departamento departamento = new Departamento(nome, local, funcionario);
		departamento.setNumeroDeCadastro(numeroDoDepartamento);
		return repositorio.editar(departamento);
	}

	public Departamento buscar(int numeroDeCadastro) throws DadoInexistenteException {
		Departamento departamento = new Departamento();
		departamento.setNumeroDeCadastro(numeroDeCadastro);
		
		Departamento retorno = new Departamento();
		retorno = repositorio.buscar(departamento);
		
		if(retorno == null)
			throw new DadoInexistenteException("Departamento");
		
		return retorno;
	}

	public boolean remover(int numeroDeCadastro) {
		Departamento departamento = new Departamento();
		departamento.setNumeroDeCadastro(numeroDeCadastro);
		return repositorio.remover(departamento);
	}


	public IteratorDepartamento buscaComParametros(String campoEscolhido,
		String valorEscolhido) {
		return null;
	}


	public IteratorDepartamento buscarTodos() {
		return null;
	}
}
