package negocios;

import interfaceNegocio.INegocioFuncionario;

import java.util.Vector;

import execoes.CamposObrigatoriosException;
import execoes.DadoInexistenteException;

import repositorio.RepDepartamento;
import repositorio.RepFuncionario;
import Iterators.IteratorFuncionario;
import basicas.Departamento;
import basicas.Endereco;
import basicas.Funcionario;
import basicas.Telefone;

public class NegocioFuncionario implements INegocioFuncionario {

	private RepFuncionario repositorio;
	private RepDepartamento repositorioDepartamento;

	public NegocioFuncionario() {
		repositorio = new RepFuncionario();
		repositorioDepartamento = new RepDepartamento();
	}

	public Funcionario buscar(int numeroDeCadastro) throws DadoInexistenteException {
		
		Funcionario funcionario = new Funcionario();
		funcionario.setNumeroDeCadastro(numeroDeCadastro);

		Funcionario retorno = repositorio.buscar(funcionario);
		if(retorno == null)
			throw new DadoInexistenteException("Funcionrio");
		
		return retorno;
	}

	public boolean cadastrar(String nome, String senha,
			String dataDeNascimento, String cpf, String rg, String cargo,
			double salario, int numeroDepartamento, Endereco endereco,
			Vector<Telefone> telefones) throws CamposObrigatoriosException, DadoInexistenteException {

		if (nome.trim().equals("") || senha.trim().equals("")
				|| rg.trim().equals("") || cargo.trim().equals("")
				|| dataDeNascimento.trim().equals("")
				|| numeroDepartamento == 0 || cpf.trim().equals("")
				|| endereco == null || telefones.size() < 1) {
			throw new CamposObrigatoriosException();
		}

		Departamento departamentoComNumero = new Departamento();
		departamentoComNumero.setNumeroDeCadastro(numeroDepartamento);

		Departamento departamento = repositorioDepartamento
				.buscar(departamentoComNumero);
				if(departamento == null)
					throw new DadoInexistenteException("Departamento");
		Funcionario supervisor = buscar(departamento
				.getNumeroContratoDoGerente());
				if(supervisor == null)
					throw new DadoInexistenteException("Supervisor");

		Funcionario funcionario = new Funcionario(nome, senha,
				dataDeNascimento, cpf, rg, cargo, salario, departamento,
				endereco, supervisor, telefones);

		return repositorio.cadastrar(funcionario);
	}

	public boolean editar(int numeroDeCadastro, String nome, String senha,
			String dataDeNascimento, String cpf, String rg, String cargo,
			double salario, int numeroDepartamento, Endereco endereco,
			Vector<Telefone> telefones) throws CamposObrigatoriosException, DadoInexistenteException {

		if (numeroDeCadastro == 0 || nome.trim().equals("")
				|| senha.trim().equals("") || rg.trim().equals("")
				|| cargo.trim().equals("")
				|| dataDeNascimento.trim().equals("")
				|| numeroDepartamento == 0 || cpf.trim().equals("")
				|| endereco == null || telefones.size() < 1) {
			throw new CamposObrigatoriosException();
		}

		Departamento departamentoComNumero = new Departamento();
		departamentoComNumero.setNumeroDeCadastro(numeroDepartamento);

		Departamento departamento = repositorioDepartamento.buscar(departamentoComNumero);
		if(departamento == null)
			throw new DadoInexistenteException("Departamento");
		Funcionario supervisor = buscar(departamento.getNumeroContratoDoGerente());
		if(supervisor == null)
			throw new DadoInexistenteException("Supervisor");

		Funcionario funcionario = new Funcionario(nome, senha,
				dataDeNascimento, cpf, rg, cargo, salario, departamento,
				endereco, supervisor, telefones);

		funcionario.setNumeroDeCadastro(numeroDeCadastro);

		return repositorio.editar(funcionario);
	}

	public boolean remover(int numeroDeCadastro) {
		Funcionario funcionario = new Funcionario();
		funcionario.setNumeroDeCadastro(numeroDeCadastro);
		return repositorio.remover(funcionario);
	}
	
	public boolean efetuarLogin(int cadastro, String senha) throws DadoInexistenteException {
		boolean logar = false;
		Funcionario funcionario = new Funcionario();
		funcionario.setNumeroDeCadastro(cadastro);
		
		Funcionario funcionarioRetorno = repositorio.buscar(funcionario);

		if (funcionarioRetorno == null) {
			throw new DadoInexistenteException("Funcionrio");
		}
		
		if (senha.equals(funcionarioRetorno.getSenha())) {
			logar = true;
		}
		
		return logar;		
	}

	public IteratorFuncionario buscaComParametros(String campoEscolhido,
			String valorEscolhido) {
		return null;
	}

	public IteratorFuncionario buscarTodos() {
		return null;
	}

}
