package negocios;

import java.sql.SQLException;
import java.util.Vector;

import execoes.CamposObrigatoriosException;
import execoes.DadoInexistenteException;

import interfaceNegocio.INegocioServico;
import repositorio.RepCliente;
import repositorio.RepServico;
import repositorio.RepVeiculo;
import Iterators.IteratorServico;
import basicas.Cliente;
import basicas.Funcionario;
import basicas.Servico;
import basicas.Veiculo;

public class NegocioServico implements INegocioServico{

	private RepServico repositorio;
	private RepCliente repositorioCliente;
	private RepVeiculo repositorioVeiculo;
	
	public NegocioServico() throws ClassNotFoundException, SQLException{
		repositorio = new RepServico();
		repositorioCliente = new RepCliente();
		repositorioVeiculo = new RepVeiculo();
	}
	
	public Servico buscar(int numeroDeCadastro) throws DadoInexistenteException {
		Servico servico = new Servico();
		servico.setNumeroDeCadastro(numeroDeCadastro);
		
		Servico retorno = repositorio.buscar(servico);
		if(retorno == null)
			throw new DadoInexistenteException("Servio");
		
		return retorno;
	}

	public boolean cadastrar(String pagamento, double valor, String dataHora,
			double desconto, String descricao, int numeroDeCadastroVeiculo,
			int numeroDeCadastroCliente, Vector<Funcionario> funcionarios) throws CamposObrigatoriosException, DadoInexistenteException, SQLException {
	
		if (pagamento.trim().equals("") || descricao.trim().equals("")
				|| dataHora.trim().equals("") || numeroDeCadastroVeiculo == 0
			    || numeroDeCadastroCliente == 0 || funcionarios.size() < 1) {
			throw new CamposObrigatoriosException();
		}
		
		Cliente cliente = new Cliente();
		cliente.setNumeroDeCadastro(numeroDeCadastroCliente);
		Cliente clienteEscolhido = repositorioCliente.buscar(cliente);
		if(clienteEscolhido == null)
			throw new DadoInexistenteException("Cliente");
		
		Veiculo veiculo = new Veiculo();
		veiculo.setNumeroDeCadastro(numeroDeCadastroVeiculo);
		Veiculo veiculoEscolhido = repositorioVeiculo.buscar(veiculo);
		if(veiculoEscolhido == null)
			throw new DadoInexistenteException("Veiculo");
		
		Servico servico = new Servico(pagamento, valor, dataHora,
				desconto, descricao, veiculoEscolhido,
				clienteEscolhido, funcionarios);
		
		return repositorio.cadastrar(servico);
	}

	public boolean editar(int numeroDeCadastroServico, String pagamento, double valor, String dataHora,
			double desconto, String descricao, int numeroDeCadastroVeiculo,
			int numeroDeCadastroCliente, Vector<Funcionario> funcionarios) throws CamposObrigatoriosException, DadoInexistenteException, SQLException {
	
		if (numeroDeCadastroServico == 0 || pagamento.trim().equals("") || descricao.trim().equals("")
				|| dataHora.trim().equals("") || numeroDeCadastroVeiculo == 0
			    || numeroDeCadastroCliente == 0 || funcionarios.size() < 1) {
			throw new CamposObrigatoriosException();
		}
		
		Cliente cliente = new Cliente();
		cliente.setNumeroDeCadastro(numeroDeCadastroCliente);
		Cliente clienteEscolhido = repositorioCliente.buscar(cliente);
		if(clienteEscolhido == null)
			throw new DadoInexistenteException("Cliente");
		
		Veiculo veiculo = new Veiculo();
		veiculo.setNumeroDeCadastro(numeroDeCadastroVeiculo);
		Veiculo veiculoEscolhido = repositorioVeiculo.buscar(veiculo);
		if(veiculoEscolhido == null)
			throw new DadoInexistenteException("Veiculo");
		
		Servico servico = new Servico(pagamento, valor, dataHora,
				desconto, descricao, veiculoEscolhido,
				clienteEscolhido, funcionarios);
		
		return repositorio.editar(servico);
	}

	public boolean remover(int numeroDeCadastro) {
		Servico servico = new Servico();
		servico.setNumeroDeCadastro(numeroDeCadastro);
		
		return repositorio.remover(servico);
	}

	public IteratorServico buscaComParametros(String campoEscolhido,
			String valorEscolhido) {
		return null;
	}

	public IteratorServico buscarTodos() {
		return null;
	}

}
