package negocios;

import execoes.CamposObrigatoriosException;
import execoes.DadoInexistenteException;
import repositorio.RepModelo;
import repositorio.RepVeiculo;
import Iterators.IteratorVeiculo;
import basicas.Modelo;
import basicas.Veiculo;
import interfaceNegocio.INegocioVeiculo;

public class NegocioVeiculo implements INegocioVeiculo {

	private RepVeiculo repositorio;
	private RepModelo repModelo;
	
	public NegocioVeiculo(){
		repositorio = new RepVeiculo();
		repModelo = new RepModelo();
	}
	
	public Veiculo buscar(int numeroDeCadastro) throws DadoInexistenteException {
		Veiculo veiculo = new Veiculo();
		veiculo.setNumeroDeCadastro(numeroDeCadastro);
		
		Veiculo retorno = repositorio.buscar(veiculo);
		if(retorno == null)
			throw new DadoInexistenteException("Veiculo");
		
		return retorno;
	}

	public boolean remover(int numeroDeCadastro) {
		Veiculo veiculo = new Veiculo();
		veiculo.setNumeroDeCadastro(numeroDeCadastro);
		
		return repositorio.remover(veiculo);
	}

	public boolean cadastrar(String ano, String cor, String placa,
			String chassi, int numeroModelo) throws CamposObrigatoriosException {
		
		if(chassi.trim().equals("") || ano.trim().equals("") || cor.trim().equals("")){
			throw new CamposObrigatoriosException();
		}
		
		Modelo modeloComNumero = new Modelo();
		modeloComNumero.setNumeroModelo(numeroModelo);
		
		Modelo modelo = repModelo.buscar(modeloComNumero);
		
		Veiculo veiculo = new Veiculo(ano, cor, placa,
			chassi, modelo);
		return repositorio.cadastrar(veiculo);
	}

	public boolean editar(int numeroCadastroVeiculo, String ano, String cor,
			String placa, String chassi, int numeroModelo) throws CamposObrigatoriosException {
		
		if(numeroCadastroVeiculo == 0 || chassi.trim().equals("") || ano.trim().equals("") || cor.trim().equals("")){
			throw new CamposObrigatoriosException();
		}
		
		Modelo modeloComNumero = new Modelo();
		modeloComNumero.setNumeroModelo(numeroModelo);
		
		Modelo modelo = repModelo.buscar(modeloComNumero);
		
		Veiculo veiculo = new Veiculo(ano, cor, placa,
				chassi, modelo);
		veiculo.setNumeroDeCadastro(numeroCadastroVeiculo);
		
		return repositorio.editar(veiculo);
	}

	public IteratorVeiculo buscaComParametros(String campoEscolhido,
			String valorEscolhido) {
		return null;
	}

	public IteratorVeiculo buscarTodos() {
		return null;
	}

}
