package repositorio;

import java.sql.Array;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Connection;
import java.util.Vector;
import Iterators.IteratorCliente;
import bancoDeDados.Conexao;
import basicas.Cliente;
import basicas.Telefone;
import interfaceRepositorio.IRepositorioCliente;

public class RepCliente implements IRepositorioCliente {

	private PreparedStatement prdSatemente;
	private Connection conexao;
	private ResultSet resultSet;

	private static final String INSERIR_CLIENTE_COM_FONE = "INSERT INTO cliente_tab ("
			+ "nome, cpf, array_telefones, numeroCad, email, nt_servicos)"
			+ "VALUES "
			+ "?, ?, array_telefones(tipo_telefone(?), tipo_telefone(?), tipo_telefone(?), tipo_telefone(?), tipo_telefone(?)), "
			+ "?, ?, nt_servicos() )";

	private static final String UPDATE_CLIENTE = "UPDATE client_tab SET "
			+ "nome = ?, cpf = ?, array_telefones = array_telefones(tipo_telefone(?), tipo_telefone(?), tipo_telefone(?), tipo_telefone(?), tipo_telefone(?)), numeroCad = ?, email = ?, nt_servicos()"
			+ "WHERE numeroCad = ?";

	private static final String DELETE_CLIENTE = "DELETE FROM cliente_tab WHERE "
			+ "numeroCad = ?";

	private static final String SELECT_CLIENTE_ESPECIFICO = "SELECT * FROM cliente_tab c, TABLE(c.array_telefones) t WHERE "
			+ "numeroCad = ?";

	public RepCliente() throws ClassNotFoundException, SQLException {
		this.conexao = (Connection) Conexao.getInstancia();
		this.prdSatemente = null;
		this.resultSet = null;
	}

	public boolean cadastrar(Cliente cliente) throws SQLException {
		boolean retorno = false;

		this.prdSatemente = this.conexao
				.prepareStatement(INSERIR_CLIENTE_COM_FONE);
		this.prdSatemente.setString(1, cliente.getNome());
		this.prdSatemente.setString(2, cliente.getCpf());

		for (int i = 0; i < cliente.getTelefones().size(); i++) {
			this.prdSatemente.setString(3 + i, cliente.getTelefones().get(i)
					.getNumero());
		}

		this.prdSatemente.setInt(8, cliente.getNumeroDeCadastro());
		this.prdSatemente.setString(9, cliente.getEmail());

		retorno = this.prdSatemente.execute();
		this.fecharTudo(this.prdSatemente, this.resultSet);

		return retorno;
	}

	public boolean editar(Cliente cliente) throws SQLException {
		boolean retorno = false;

		this.prdSatemente = this.conexao.prepareStatement(UPDATE_CLIENTE);
		this.prdSatemente.setString(1, cliente.getNome());
		this.prdSatemente.setString(2, cliente.getCpf());

		for (int i = 0; i < cliente.getTelefones().size(); i++) {
			this.prdSatemente.setString(3 + i, cliente.getTelefones().get(i)
					.getNumero());
		}

		this.prdSatemente.setInt(8, cliente.getNumeroDeCadastro());
		this.prdSatemente.setString(9, cliente.getEmail());
		this.prdSatemente.setInt(10, cliente.getNumeroDeCadastro());

		retorno = this.prdSatemente.execute();
		this.fecharTudo(this.prdSatemente, this.resultSet);

		return retorno;
	}

	public boolean remover(Cliente cliente) throws SQLException {
		boolean retorno = false;

		this.prdSatemente = this.conexao.prepareStatement(DELETE_CLIENTE);
		this.prdSatemente.setInt(1, cliente.getNumeroDeCadastro());

		retorno = this.prdSatemente.execute();
		this.fecharTudo(prdSatemente, resultSet);

		return retorno;
	}

	public Cliente buscar(Cliente cliente) throws SQLException {
		Cliente retorno = new Cliente();

		this.prdSatemente = this.conexao
				.prepareStatement(SELECT_CLIENTE_ESPECIFICO);
		this.prdSatemente.setInt(1, cliente.getNumeroDeCadastro());
		this.resultSet = this.prdSatemente.executeQuery();

		while (resultSet.next() == true) {
			String nome = this.resultSet.getString("nome");
			String cpf = this.resultSet.getString("cpf");
			Array telefone = this.resultSet.getArray(3);
			Vector<Telefone> telefones = new Vector<Telefone>();
			String email = this.resultSet.getString("email");

			for (int i = 0; i < 5; i++) {
				telefones.add(new Telefone((String) telefone.getArray(0, i)));
			}

			retorno.setNome(nome);
			retorno.setCpf(cpf);
			retorno.setEmail(email);
			retorno.setTelefones(telefones);

		}

		return retorno;
	}

	private void fecharTudo(PreparedStatement prdSatemente, ResultSet resultSet)
			throws SQLException {
		prdSatemente.close();
		resultSet.close();
	}

	public IteratorCliente buscarComParametros(String campoEscolhido,
			String valor) {
		return null;
	}

	public IteratorCliente buscarTodos() {
		return null;
	}
}
