package aeronave;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.Date;
import java.sql.SQLException;

import javax.swing.ImageIcon;

import aeronave.exception.ArquivoMuitoGrandeException;
import aeronave.exception.CodigoExistenteException;
import aeronave.exception.CodigoInexistenteException;
import aeronave.exception.CodigoInvalidoException;
import aeronave.exception.ImagemInvalidaException;

public class NegocioAeronave {
	RepositorioAeronave repositorio;
	public NegocioAeronave(Connection conexao) throws SQLException {
		repositorio = new RepositorioAeronave(conexao);
	}

	public void inserirAeronave(String codigo, String modelo, String companhia, Date ultimaManutencao, int horasDeVoo, File img) throws SQLException, CodigoInvalidoException, ImagemInvalidaException, IOException, CodigoExistenteException, ArquivoMuitoGrandeException {
		if(consultarCodigo(codigo) != null) {
			throw new CodigoExistenteException();
		}
		Aeronave nova = new Aeronave(codigo, modelo, companhia, ultimaManutencao, horasDeVoo);
		if(img != null) {
			long tamanho = img.length();
			if (tamanho > Integer.MAX_VALUE) {
				throw new ArquivoMuitoGrandeException();
			}
			byte b[] = new byte[(int)tamanho];
			InputStream is = new FileInputStream(img);
			is.read(b);
			ImageIcon imagem = new ImageIcon(b);
			if(imagem.getIconHeight() > 200 || imagem.getIconWidth() > 300) {
				throw new ImagemInvalidaException();
			}
		}
			repositorio.inserirAeronave(nova, img);
	}

	public ImageIcon getFoto(String codigo) throws SQLException {
		return repositorio.getFoto(codigo);
	}

	public void removerAeronave(String codigo) throws SQLException, CodigoInvalidoException, CodigoInexistenteException {
		new Aeronave(codigo, "", "", null, 0);
		if(consultarCodigo(codigo) == null) throw new CodigoInexistenteException();
		repositorio.removerAeronave(codigo);
	}

	public Aeronave consultarCodigo(String codigo) throws SQLException, CodigoInvalidoException {
		return repositorio.consultarCodigo(codigo);
	}

	public IteratorAeronave consultarCompanhia(String companhia) throws SQLException, CodigoInvalidoException {
		return repositorio.consultarCompanhia(companhia);
	}

	public IteratorAeronave consultarModelo(String modelo) throws SQLException, CodigoInvalidoException {
		return repositorio.consultarModelo(modelo);
	}

}
