package aeronave;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.sql.Blob;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import javax.swing.ImageIcon;

import aeronave.exception.CodigoInvalidoException;

class RepositorioAeronave {
	private PreparedStatement insert;
	private PreparedStatement remove;
	private PreparedStatement consultarCodigo;
	private PreparedStatement consultarFoto;
	private PreparedStatement consultarCompanhia;
	private PreparedStatement consultarModelo;
	public RepositorioAeronave(Connection conexao) throws SQLException {
		remove = conexao.prepareStatement("delete from aeronave where codigo = ?");
		consultarCodigo = conexao.prepareStatement("select * from aeronave where codigo = ?");
		consultarFoto = conexao.prepareStatement("select foto from aeronave where codigo = ?");
		consultarModelo = conexao.prepareStatement("select * from aeronave where modelo like ?");
		consultarCompanhia = conexao.prepareStatement("select * from aeronave where companhia = ?");
		insert = conexao.prepareStatement("insert into aeronave(codigo, modelo, companhia, ultima_manutencao, horas_de_voo, foto)" +
		"values(?,?,?,?,?,?)");
	}

	public void inserirAeronave(Aeronave aeronave, File img) throws SQLException, FileNotFoundException {
		insert.setString(1, aeronave.getCodigo());
		insert.setString(2, aeronave.getModelo());
		insert.setString(3, aeronave.getCompanhia());
		insert.setDate(4, aeronave.getUltimaManutencao());
		insert.setInt(5, aeronave.getHorasDeVoo());
		if(img != null) {
			FileInputStream stream = new FileInputStream(img);
			insert.setBinaryStream(6, stream, (int)img.length());
		}
		else {
			insert.setNull(6, Types.BLOB);
		}
		insert.execute();
	}

	ImageIcon getFoto(String codigo) throws SQLException {
		consultarFoto.setString(1, codigo);
		ResultSet rs = consultarFoto.executeQuery();
		if(rs.next()) {
			Blob blob = rs.getBlob("foto");
			if(blob == null) return null;
			int tamanho = (int)blob.length();
			rs.close();
			return new ImageIcon(blob.getBytes(1, tamanho));
		}
		rs.close();
		return null;
	}

	public void removerAeronave(String codigo) throws SQLException {
		remove.setString(1, codigo);
		remove.execute();
	}

	public Aeronave consultarCodigo(String codigo) throws SQLException, CodigoInvalidoException {
		codigo = codigo.toUpperCase();
		consultarCodigo.setString(1, codigo);
		ResultSet rs = consultarCodigo.executeQuery();
		if(rs.next()) {
			Aeronave retorno = new Aeronave(codigo, rs.getString("modelo"), rs.getString("companhia"), rs.getDate("ultima_manutencao"), rs.getInt("horas_de_voo"));
			rs.close();
			return retorno;
		}
		return null;
	}

	public IteratorAeronave consultarCompanhia(String companhia) throws SQLException, CodigoInvalidoException {
		companhia = companhia.toUpperCase();
		consultarCompanhia.setString(1, companhia);
		ResultSet rs = consultarCompanhia.executeQuery();
		IteratorAeronave retorno = new IteratorAeronave(rs);
		return retorno;
	}

	public IteratorAeronave consultarModelo(String modelo) throws SQLException, CodigoInvalidoException {
		modelo = '%' + modelo.toUpperCase() + '%';
		consultarModelo.setString(1, modelo);
		ResultSet rs = consultarModelo.executeQuery();
		IteratorAeronave retorno = new IteratorAeronave(rs);
		return retorno;
	}
}
